@@ -34,12 +34,11 @@ use warnings;
 use base 'Template::Plugin';
 
 use File::Spec;
-use LaTeX::Driver 0.07;
+use LaTeX::Driver 0.06;
 use LaTeX::Encode;
-use LaTeX::Table;
 
 
-our $VERSION = "3.00";
+our $VERSION = "3.00_02";
 our $DEBUG   = 0 unless defined $DEBUG;
 our $ERROR   = '';
 our $FILTER  = 'latex';
@@ -92,8 +91,7 @@ sub new {
     # now define the filter and return the plugin
     $context->define_filter('latex_encode', [ $encode_filter_factory => 1 ]);
     $context->define_filter($options->{filter} || $FILTER, [ $filter_factory => 1 ]);
-
-    return bless $plugin, $class;
+    return $plugin;
 }
 
 
@@ -139,7 +137,7 @@ sub _tt_latex_filter {
 
     if ($output) {
         my $path = $context->config->{ OUTPUT_PATH }
-            or $class->_throw('OUTPUT_PATH is not set');
+            or $class->throw('OUTPUT_PATH is not set');
         $output = File::Spec->catfile($path, $output);
     }
     else {
@@ -160,7 +158,7 @@ sub _tt_latex_filter {
         $drv->run;
     };        
     if (my $e = LaTeX::Driver::Exception->caught()) {
-        $class->_throw("$e");
+        $class->throw("$e");
     }
 
     # Return the text if it was output to a scalar variable, otherwise
@@ -197,24 +195,12 @@ sub _setup_texinput_paths {
 }
 
 
-sub _throw {
+sub throw {
     my $self = shift;
     die Template::Exception->new( $THROW => join('', @_) );
 }
 
 
-sub table {
-    my $args  = ref($_[-1]) eq 'HASH' ? pop(@_) : { };
-    my ($table, $text);
-    eval {
-        $table = LaTeX::Table->new($args);
-        $text  = $table->generate_string;
-    };
-    if ($@) {
-        die Template::Exception->new( $THROW => $@ );
-    }
-    return $text;
-}
 
 
 1;
@@ -227,7 +213,7 @@ Template::Plugin::Latex - Template Toolkit plugin for Latex
 
 =head1 VERSION
 
-This documentation refers to C<Template::Plugin::Latex> version 3.00_03
+This documentation refers to C<Template::Plugin::Latex> version 3.00_01
 
 =head1 SYNOPSIS
 
@@ -349,29 +335,6 @@ C<use_textcomp = 0> turns off these encodings.
 
 =back
 
-=head2 C<table()>
-
-The C<table()> function provides an interface to the C<LaTeX::Table> module.
-
-The following example shows how a simple table can be set up.
-
-    [%- USE Latex;
-
-        data = [ [ 'London', 'United Kingdom' ],
-                 [ 'Berlin', 'Germany'        ],
-                 [ 'Paris',  'France'         ],
-                 [ 'Washington', 'USA'        ] ] );
-
-        text = Latex.table( caption  = 'Capitol Cities',
-                            label    = 'table:capitols',
-                            headings = [ [ 'City', 'Country' ] ],
-                            data     = data );
-     -%]
-                            
-The variable C<text> will hold the LaTeX commands to typeset the table
-and can be further interpolated into a LaTeX document template.
-
-TO BE EXPANDED.
 
 
 =head1 OLD DOCUMENTATION
@@ -502,7 +465,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 =head1 SEE ALSO
 
-L<Template::Latex>, L<LaTeX::Driver>, L<LaTeX::Table>
+L<Template::Latex>, L<LaTeX::Driver>
 
 =cut
 
